@@ -1,6 +1,6 @@
 /*
- * CANT - A C implementation of the Apache/Tomcat ANT build system
- * Copyright (c) 2001-2003 Greg Banks <gnb@alphalink.com.au>
+ * ggcov - A GTK frontend for exploring gcov coverage data
+ * Copyright (c) 2001-2005 Greg Banks <gnb@alphalink.com.au>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 
 #include "common.h"
 
-CVSID("$Id: common.c,v 1.12 2004/03/16 20:26:53 gnb Exp $");
+CVSID("$Id: common.c,v 1.17 2005/05/22 12:47:56 gnb Exp $");
 
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
@@ -114,10 +114,12 @@ static struct
 {"bb",       	F(D_BB)},
 {"bbg",      	F(D_BBG)},
 {"da",       	F(D_DA)},
+{"io",       	F(D_IO)},
 {"cgraph",   	F(D_CGRAPH)},
 {"solve",    	F(D_SOLVE)},
 {"stabs",    	F(D_STABS)},
 {"dwarf",    	F(D_DWARF)},
+{"elf",    	F(D_ELF)},
 {"dump",     	F(D_DUMP)},
 {"report",     	F(D_REPORT)},
 
@@ -130,8 +132,11 @@ static struct
 {"fileswin", 	F(D_FILESWIN)},
 {"graphwin", 	F(D_GRAPHWIN)},
 {"graph2win",	F(D_GRAPH2WIN)},
+{"legowin",	F(D_LEGOWIN)},
 {"reportwin",	F(D_REPORTWIN)},
 
+{"web",  	F(D_WEB)},
+
 #define SPECIALS_START     (const char *)1
 {SPECIALS_START, 0},
 
