@@ -1,6 +1,6 @@
 /*
  * ggcov - A GTK frontend for exploring gcov coverage data
- * Copyright (c) 2001-2003 Greg Banks <gnb@alphalink.com.au>
+ * Copyright (c) 2001-2005 Greg Banks <gnb@alphalink.com.au>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,10 +58,12 @@ typedef enum
     D_BB,
     D_BBG,
     D_DA,
+    D_IO,
     D_CGRAPH,
     D_SOLVE,
     D_STABS,
     D_DWARF,
+    D_ELF,
     D_DUMP,
     D_REPORT,
     /* gui related features */
@@ -74,7 +76,10 @@ typedef enum
     D_FILESWIN,
     D_GRAPHWIN,
     D_GRAPH2WIN,
+    D_LEGOWIN,
     D_REPORTWIN,
+    /* web related features */
+    D_WEB,
     /* bitwise OR in D_VERBOSE to enable printing only when verbose */
 #define _D_VERBOSE_SHIFT    7
     D_VERBOSE=(1<<_D_VERBOSE_SHIFT)
