@@ -1,6 +1,6 @@
 /*
  * ggcov - A GTK frontend for exploring gcov coverage data
- * Copyright (c) 2001-2003 Greg Banks <gnb@alphalink.com.au>
+ * Copyright (c) 2001-2004 Greg Banks <gnb@alphalink.com.au>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,16 +28,16 @@
 #include "summarywin.H"
 #include "callswin.H"
 #include "callgraphwin.H"
-#include "callgraph2win.H"
+#include "diagwin.H"
+#include "callgraph_diagram.H"
+#include "lego_diagram.H"
 #include "functionswin.H"
 #include "fileswin.H"
 #include "reportwin.H"
-#if !GTK2
 #include <libgnomeui/libgnomeui.h>
-#endif
 #include "fakepopt.h"
 
-CVSID("$Id: ggcov.c,v 1.42 2004/04/03 01:31:21 gnb Exp $");
+CVSID("$Id: ggcov.c,v 1.47 2005/06/13 07:08:51 gnb Exp $");
 
 #define DEBUG_GTK 1
 
@@ -49,6 +49,7 @@ static char *suppressed_ifdefs = 0;
 static char *object_dir = 0;
 static const char *debug_str = 0;
 static const char ** debug_argv;
+static int solve_fuzzy_flag = FALSE;
 
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 /*
@@ -96,6 +97,8 @@ read_gcov_files(void)
     if (files == 0)
     	return;
 
+    cov_function_t::set_solve_fuzzy_flag(solve_fuzzy_flag);
+
     if (suppressed_ifdefs != 0)
     {
     	tok_t tok(/*force copy*/(const char *)suppressed_ifdefs, ", \t");
@@ -298,11 +301,19 @@ on_windows_new_callgraphwin_activated(GtkWidget *w, gpointer userdata)
 static void
 on_windows_new_callgraph2win_activated(GtkWidget *w, gpointer userdata)
 {
-
-    callgraph2win_t *cgw;
+    diagwin_t *lw;
     
-    cgw = new callgraph2win_t;
-    cgw->show();
+    lw = new diagwin_t(new callgraph_diagram_t);
+    lw->show();
+}
+
+static void
+on_windows_new_legowin_activated(GtkWidget *w, gpointer userdata)
+{
+    diagwin_t *lw;
+    
+    lw = new diagwin_t(new lego_diagram_t);
+    lw->show();
 }
 
 static void
@@ -326,7 +337,7 @@ on_windows_new_reportwin_activated(GtkWidget *w, gpointer userdata)
     rw->show();
 }
 
-#include "ui/icon.xpm"
+#include "ui/ggcov32.xpm"
 
 static void
 ui_create(void)
@@ -343,12 +354,14 @@ ui_create(void)
     			      on_windows_new_callgraphwin_activated, 0);
     ui_register_windows_entry("New Call Graph...",
     			      on_windows_new_callgraph2win_activated, 0);
+    ui_register_windows_entry("New Lego Diagram...",
+    			      on_windows_new_legowin_activated, 0);
     ui_register_windows_entry("New Source...",
     			      on_windows_new_sourcewin_activated, 0);
     ui_register_windows_entry("New Report...",
     			      on_windows_new_reportwin_activated, 0);
 
-    ui_set_default_icon(icon_xpm);
+    ui_set_default_icon(ggcov32_xpm);
 
     prefs.load();
 
@@ -408,6 +421,15 @@ static struct poptOption popt_options[] =
 	"directory in which to find .o,.bb,.bbg,.da files", /* descrip */
 	0	    	    	    	    	/* argDescrip */
     },
+    {
+    	"solve-fuzzy",    	    	    	/* longname */
+	'F',  	    	    	    	    	/* shortname */
+	POPT_ARG_NONE,  	    	    	/* argInfo */
+	&solve_fuzzy_flag,     	    	    	/* arg */
+	0,  	    	    	    	    	/* val 0=don't return */
+	"whether to be tolerant of inconsistent arc counts", /* descrip */
+	0	    	    	    	    	/* argDescrip */
+    },
     {
     	"debug",	    	    	    	/* longname */
 	'D',  	    	    	    	    	/* shortname */
