@@ -1,6 +1,6 @@
 /*
  * ggcov - A GTK frontend for exploring gcov coverage data
- * Copyright (c) 2001-2003 Greg Banks <gnb@alphalink.com.au>
+ * Copyright (c) 2001-2005 Greg Banks <gnb@alphalink.com.au>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #include "string_var.H"
 #include "tok.H"
 
-CVSID("$Id: ui.c,v 1.22 2003/11/03 23:02:50 gnb Exp $");
+CVSID("$Id: ui.c,v 1.29 2005/03/18 15:39:06 gnb Exp $");
 
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
@@ -467,6 +467,8 @@ ui_menu_add_seperator(GtkWidget *menu)
 }
      
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
+#if !GTK2
+/* column sorting is trivial in gtk2.x, extremely painful in gtk1.2 */
 
 static const char ui_clist_arrow_key[] = "ui_clist_arrow_key";
 
@@ -605,11 +607,14 @@ ui_clist_set_sort_type(GtkCList *clist, GtkSortType type)
       GTK_SHADOW_OUT);
 }
 
+#endif /* !GTK2 */
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
 gpointer
-ui_clist_double_click_data(GtkCList *clist, GdkEvent *event)
+ui_list_double_click_data(GtkWidget *w, GdkEvent *event, int column )
 {
+#if !GTK2
+    GtkCList *clist = GTK_CLIST(w);
     int row, col;
 
     if (event->type == GDK_2BUTTON_PRESS &&
@@ -618,16 +623,12 @@ ui_clist_double_click_data(GtkCList *clist, GdkEvent *event)
 				     (int)event->button.y,
 				     &row, &col))
     {
-    	dprintf2(D_UICORE, "ui_clist_double_click_data: row=%d col=%d\n", row, col);
+    	dprintf2(D_UICORE, "ui_list_double_click_data: row=%d col=%d\n", row, col);
 	return gtk_clist_get_row_data(clist, row);
     }
     return 0;
-}
-
-#if GTK2
-gpointer
-ui_tree_view_double_click_data(GtkTreeView *tv, GdkEvent *event, int column)
-{
+#else
+    GtkTreeView *tv = GTK_TREE_VIEW(w);
     GtkTreeModel *model;
     GtkTreePath *path = 0;
     GtkTreeIter iter;
@@ -643,7 +644,7 @@ ui_tree_view_double_click_data(GtkTreeView *tv, GdkEvent *event, int column)
     	if (debug_enabled(D_UICORE))
 	{
     	    string_var path_str = gtk_tree_path_to_string(path);
-    	    duprintf1("ui_tree_view_double_click_data: path=\"%s\"\n",
+    	    duprintf1("ui_list_double_click_data: path=\"%s\"\n",
 	    	    	    path_str.data());
     	}
     	model = gtk_tree_view_get_model(tv);
@@ -654,14 +655,29 @@ ui_tree_view_double_click_data(GtkTreeView *tv, GdkEvent *event, int column)
 	return data;
     }
     return 0;
-}
 #endif
+}
+
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
+
+void
+ui_list_set_column_visibility(GtkWidget *w, int col, gboolean vis)
+{
+#if !GTK2
+    gtk_clist_set_column_visibility(GTK_CLIST(w), col, vis);
+#else
+    gtk_tree_view_column_set_visible(
+    	    gtk_tree_view_get_column(GTK_TREE_VIEW(w), col),
+	    vis);
+#endif
+}
 
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
 #if GTK2
 static PangoFontDescription *ui_text_font_desc;
 #else
+/* we have to fake a *lot* of stuff for gtk1.2 */
 static GdkFont *ui_text_font;
 
 struct ui_text_tag_s
@@ -746,6 +762,7 @@ ui_text_setup(GtkWidget *w)
 #endif /* !GTK2 */
 }
 
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
 int
 ui_text_font_width(GtkWidget *w)
@@ -762,6 +779,7 @@ ui_text_font_width(GtkWidget *w)
 #endif /* !GTK2 */
 }
 
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
 ui_text_tag *
 ui_text_create_tag(GtkWidget *w, const char *name, GdkColor *fg)
@@ -786,6 +804,7 @@ ui_text_create_tag(GtkWidget *w, const char *name, GdkColor *fg)
 #endif /* !GTK2 */
 }   
 
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
 gfloat
 ui_text_vscroll_sample(GtkWidget *w)
@@ -813,6 +832,8 @@ ui_text_vscroll_restore(GtkWidget *w, gfloat vs)
 #endif /* !GTK2 */
 }
 
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
+
 void
 ui_text_begin(GtkWidget *w)
 {
@@ -878,6 +899,7 @@ ui_text_end(GtkWidget *w)
 #endif /* !GTK2 */
 }
 
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
 void
 ui_text_select_lines(GtkWidget *w, unsigned long startline, unsigned long endline)
@@ -887,6 +909,9 @@ ui_text_select_lines(GtkWidget *w, unsigned long startline, unsigned long endlin
     GtkTextBuffer *buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(w));
     GtkTextIter start, end;
     
+    if (startline > 1)
+    	startline--;	    /* workaround gtk bug */
+    
     gtk_text_buffer_get_iter_at_line(buffer, &start, startline);
     gtk_text_buffer_get_iter_at_line(buffer, &end, endline);
 
@@ -954,6 +979,7 @@ ui_text_select_lines(GtkWidget *w, unsigned long startline, unsigned long endlin
 #endif /* !GTK2 */
 }
 
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
 void
 ui_text_ensure_visible(GtkWidget *w, unsigned long line)
@@ -977,6 +1003,7 @@ ui_text_ensure_visible(GtkWidget *w, unsigned long line)
 #endif
 }
 
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
 #if !GTK2
 static unsigned long
@@ -1068,6 +1095,7 @@ ui_text_get_selected_lines(
 #endif /* !GTK2 */
 }
 
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
 char *
 ui_text_get_contents(GtkWidget *w)
